pub struct ppcf128(/* private fields */);🔬This is a nightly-only experimental API. (
powerpc_ppcf128 #163323)Available on PowerPC and (PowerPC or PowerPC64) only.
The IBM extended-precision (double-double) floating-point type.
Implementations
Sourceimpl ppcf128
impl ppcf128
Sourcepub const fn to_ne_bytes(self) -> [u8; 16]
🔬This is a nightly-only experimental API. (powerpc_ppcf128 #163323)
pub const fn to_ne_bytes(self) -> [u8; 16]
powerpc_ppcf128 #163323)Returns the memory representation of this floating point number as a byte array in native byte order.
Sourcepub const fn to_components(self) -> (f64, f64)
🔬This is a nightly-only experimental API. (powerpc_ppcf128 #163323)
pub const fn to_components(self) -> (f64, f64)
powerpc_ppcf128 #163323)Returns the large and small component of this floating point number.